@@ -15,8 +15,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -47,7 +47,7 @@ const unsigned short int split_flag_y = 4;
 // patch misalignment due to higher subdivision a bit lower in the y direction.
 const unsigned short int patch_flag_y = 8;
 // We flag vertices in faces that should be two faces over each edge of the
-// panormama's 180 degree seem, such that by flipping the flagged vertices to
+// panorama's 180 degree seem, such that by flipping the flagged vertices to
 // the other side we get a valid face for one side, and by flipping those not
 // flagged we get the other.
 const unsigned short int vertex_side_flag_start = 16;
@@ -268,6 +268,7 @@ void VertexCoordRemapper::DiscontinuityFlip(double vertex_c[2])
         case HuginBase::PanoramaOptions::FULL_FRAME_FISHEYE:
         case HuginBase::PanoramaOptions::STEREOGRAPHIC:
         case HuginBase::PanoramaOptions::LAMBERT_AZIMUTHAL:
+        case HuginBase::PanoramaOptions::HAMMER_AITOFF:
         case HuginBase::PanoramaOptions::ORTHOGRAPHIC:
         case HuginBase::PanoramaOptions::EQUISOLID:
         case HuginBase::PanoramaOptions::THOBY_PROJECTION:
@@ -301,7 +302,9 @@ void VertexCoordRemapper::DiscontinuityFlip(double vertex_c[2])
             if (vertex_c[1] < y_midpoint) vertex_c[1] += y_add_360;
             else vertex_c[1] -= y_add_360;
             break;
-        
+        default:
+            // all other projection, no special handling
+            break;
     }
 }
 
@@ -613,6 +616,7 @@ void VertexCoordRemapper::TestSubdivide(unsigned int node_id)
             case HuginBase::PanoramaOptions::FULL_FRAME_FISHEYE:
             case HuginBase::PanoramaOptions::STEREOGRAPHIC:
             case HuginBase::PanoramaOptions::LAMBERT_AZIMUTHAL:
+            case HuginBase::PanoramaOptions::HAMMER_AITOFF:
                 // A mesh covering the extremities of a disk projection should
                 // be using a TexCoordRemapper instead, otherwise, a point
                 // mapping to the border will be stretched across the disk.
@@ -623,8 +627,6 @@ void VertexCoordRemapper::TestSubdivide(unsigned int node_id)
             case HuginBase::PanoramaOptions::LAMBERT:
             case HuginBase::PanoramaOptions::MILLER_CYLINDRICAL:
             case HuginBase::PanoramaOptions::PANINI:
-			case HuginBase::PanoramaOptions::BIPLANE:
-			case HuginBase::PanoramaOptions::TRIPLANE:
             case HuginBase::PanoramaOptions::GENERAL_PANINI:
                 // Cylinderical-like projections have the seam across the left
                 // and right edge. We'll take any face within the middle third
@@ -723,6 +725,9 @@ void VertexCoordRemapper::TestSubdivide(unsigned int node_id)
                 break;
             case HuginBase::PanoramaOptions::ALBERS_EQUAL_AREA_CONIC:
                 break;
+            default:
+                // all other projections, no special handling
+                break;
         }
         if (noncontinuous)
         {
@@ -923,12 +928,11 @@ unsigned int VertexCoordRemapper::Tree::GetNext()
     //     point, we trace down the tree until we get to a leaf.
     if (cur_tree_node != 0)
     {
-        unsigned int xd = 0, yd = 0;
         bool done = false;
         while (!done && cur_tree_node != 0)
         {
-            xd = x % 2;
-            yd = y % 2;
+            unsigned int xd = x % 2;
+            unsigned int yd = y % 2;
             x /= 2;
             y /= 2;
             row_size /= 2;
